xi_covutils API documentation

Top

# xi_covutils module

## Sub-modules

xi_covutils.aux

xi_covutils.clustering

Clustering functions

xi_covutils.distances

Functions and classes to work with residue distances in proteins structures

xi_covutils.msa

Functions to work with MSA files

xi_covutils.pdbmapper

Functions to map postions from PDB files to sequence files

xi_covutils.read_results

Read results from covariation files

xi_covutils.roc

Functions to compute ROC curves and calculate AUC scores.

xi_covutils.smooth

Functions to compute smooth covariation scores